@@ -18,8 +18,8 @@
 #ifndef _TK
 #define _TK
 
-#define TK_VERSION "4.0"
-#define TK_MAJOR_VERSION 4
+#define TK_VERSION "8.0"
+#define TK_MAJOR_VERSION 8
 #define TK_MINOR_VERSION 0
 #define TK_PORT_CURSES
 
@@ -353,15 +353,6 @@ typedef struct Tk_ConfigSpec {
 #define TK_CONFIG_OPTION_SPECIFIED	0x10
 #define TK_CONFIG_USER_BIT		0x100
 
-/*
- * Bits to pass to Tk_CreateFileHandler to indicate what sorts
- * of events are of interest:
- */
-
-#define TK_READABLE	1
-#define TK_WRITABLE	2
-#define TK_EXCEPTION	4
-
 /*
  * Special return value from Tk_FileProc2 procedures indicating that
  * an event was successfully processed.
@@ -374,12 +365,12 @@ typedef struct Tk_ConfigSpec {
  * for some kinds of events:
  */
 
-#define TK_DONT_WAIT		1
-#define TK_X_EVENTS		2
-#define TK_FILE_EVENTS		4
-#define TK_TIMER_EVENTS		8
-#define TK_IDLE_EVENTS		0x10
-#define TK_ALL_EVENTS		0x1e
+#define TK_DONT_WAIT		TCL_DONT_WAIT
+#define TK_X_EVENTS		TCL_WINDOW_EVENTS
+#define TK_FILE_EVENTS		TCL_FILE_EVENTS
+#define TK_TIMER_EVENTS		TCL_TIMER_EVENTS
+#define TK_IDLE_EVENTS		TCL_IDLE_EVENTS
+#define TK_ALL_EVENTS		TCL_ALL_EVENTS
 
 /*
  * Priority levels to pass to Tk_AddOption:
@@ -635,12 +626,9 @@ typedef void (Tk_TimerProc) _ANSI_ARGS_((ClientData clientData));
 
 EXTERN void		Tk_AddOption _ANSI_ARGS_((Tk_Window tkwin, char *name,
 			    char *value, int priority));
-EXTERN void		Tk_BackgroundError _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN void		Tk_BindEvent _ANSI_ARGS_((Tk_BindingTable bindingTable,
 			    XEvent *eventPtr, Tk_Window tkwin, int numObjects,
 			    ClientData *objectPtr));
-EXTERN void		Tk_CancelIdleCall _ANSI_ARGS_((Tk_IdleProc *idleProc,
-			    ClientData clientData));
 EXTERN int		Tk_ConfigureInfo _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Window tkwin, Tk_ConfigSpec *specs,
 			    char *widgRec, char *argvName, int flags));
@@ -694,9 +682,6 @@ EXTERN void		Tk_DeleteTimerHandler _ANSI_ARGS_((
 EXTERN void		Tk_DestroyWindow _ANSI_ARGS_((Tk_Window tkwin));
 EXTERN char *		Tk_DisplayName _ANSI_ARGS_((Tk_Window tkwin));
 EXTERN int		Tk_DoOneEvent _ANSI_ARGS_((int flags));
-EXTERN void		Tk_DoWhenIdle _ANSI_ARGS_((Tk_IdleProc *proc,
-			    ClientData clientData));
-EXTERN int		Tk_EventInit _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN void		Tk_EventuallyFree _ANSI_ARGS_((ClientData clientData,
 			    Tk_FreeProc *freeProc));
 EXTERN void		Tk_FreeOptions _ANSI_ARGS_((Tk_ConfigSpec *specs,
