@@ -1005,7 +1005,7 @@ Tk_BindEvent(bindingTable, eventPtr, tkwin, numObjects, objectPtr)
 		break;
 	    } else {
 		Tcl_AddErrorInfo(interp, "\n    (command bound to event)");
-		Tk_BackgroundError(interp);
+		Tcl_BackgroundError(interp);
 		break;
 	    }
 	}
@@ -1073,7 +1073,7 @@ ChangeScreen(interp, dispName)
     if (code != TCL_OK) {
 	Tcl_AddErrorInfo(interp,
 		"\n    (changing screen in event binding)");
-	Tk_BackgroundError(interp);
+	Tcl_BackgroundError(interp);
     }
 }
 
@@ -1137,6 +1137,7 @@ FindSequence(interp, bindPtr, object, eventString, create, maskPtr)
     size_t sequenceSize;
     unsigned long eventMask;
     PatternTableKey key;
+    char error_buffer[100];
 
     /*
      *-------------------------------------------------------------
@@ -1181,8 +1182,10 @@ FindSequence(interp, bindPtr, object, eventString, create, maskPtr)
 		if (isprint(UCHAR(*p))) {
 		    patPtr->detail = *p;
 		} else {
-		    sprintf(interp->result,
+         
+		    sprintf(error_buffer,
 			    "bad ASCII character 0x%x", (unsigned char) *p);
+		    Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
 		    goto error;
 		}
 	    }
@@ -1272,14 +1275,14 @@ FindSequence(interp, bindPtr, object, eventString, create, maskPtr)
 		}
 	    }
 	} else if (patPtr->eventType == -1) {
-	    interp->result = "no event type or button # or keysym";
+	    Tcl_SetResult(interp, "no event type or button # or keysym", TCL_STATIC);
 	    goto error;
 	}
 	while ((*p == '-') || isspace(UCHAR(*p))) {
 	    p++;
 	}
 	if (*p != '>') {
-	    interp->result = "missing \">\" in binding";
+	    Tcl_SetResult(interp, "missing \">\" in binding", TCL_STATIC);
 	    goto error;
 	}
 	p++;
@@ -1308,7 +1311,7 @@ FindSequence(interp, bindPtr, object, eventString, create, maskPtr)
      */
 
     if (numPats == 0) {
-	interp->result = "no events specified in binding";
+	Tcl_SetResult(interp, "no events specified in binding", TCL_STATIC);
 	goto error;
     }
     patPtr = &pats[EVENT_BUFFER_SIZE-numPats];
@@ -1369,7 +1372,7 @@ FindSequence(interp, bindPtr, object, eventString, create, maskPtr)
     return NULL;
 
     unsupported:
-    interp->result = "Unsupported event type";
+    Tcl_SetResult(interp, "Unsupported event type", TCL_STATIC);
     *maskPtr = CTK_UNSUPPORTED_EVENT_MASK;
     return NULL;
 }
